@@ -130,7 +130,6 @@ def test_env_async():
     return env
 
 
-@pytest.mark.imports
 class TestAsyncImports(object):
     def test_context_imports(self, test_env_async):
         t = test_env_async.from_string('{% import "module" as m %}{{ m.test() }}')
@@ -180,8 +179,6 @@ class TestAsyncImports(object):
         assert not hasattr(m, "notthere")
 
 
-@pytest.mark.imports
-@pytest.mark.includes
 class TestAsyncIncludes(object):
     def test_context_include(self, test_env_async):
         t = test_env_async.from_string('{% include "header" %}')
@@ -279,8 +276,6 @@ class TestAsyncIncludes(object):
         assert t.render().strip() == "(FOO)"
 
 
-@pytest.mark.core_tags
-@pytest.mark.for_loop
 class TestAsyncForLoop(object):
     def test_simple(self, test_env_async):
         tmpl = test_env_async.from_string("{% for item in seq %}{{ item }}{% endfor %}")
@@ -583,3 +578,14 @@ class TestAsyncForLoop(object):
     def test_awaitable_property_slicing(self, test_env_async):
         t = test_env_async.from_string("{% for x in a.b[:1] %}{{ x }}{% endfor %}")
         assert t.render(a=dict(b=[1, 2, 3])) == "1"
+
+
+def test_namespace_awaitable(test_env_async):
+    async def _test():
+        t = test_env_async.from_string(
+            '{% set ns = namespace(foo="Bar") %}{{ ns.foo }}'
+        )
+        actual = await t.render_async()
+        assert actual == "Bar"
+
+    run(_test())
